@@ -1,5 +1,5 @@
 ;;; GnuTLS --- Guile bindings for GnuTLS.
-;;; Copyright (C) 2007-2012, 2014, 2015 Free Software Foundation, Inc.
+;;; Copyright (C) 2007-2012, 2014, 2015, 2016 Free Software Foundation, Inc.
 ;;;
 ;;; GnuTLS is free software; you can redistribute it and/or
 ;;; modify it under the terms of the GNU Lesser General Public
@@ -412,10 +412,16 @@
            openpgp-certificate-format/raw
            openpgp-certificate-format/base64))
 
+(cond-expand
+  ((not guile-2)                                  ;silly 1.8
+   (define-macro (eval-when foo a b)
+     `(begin ,a ,b)))
+  (else #t))
+
 (eval-when (expand load eval)
   (define %libdir
     (or (getenv "GNUTLS_GUILE_EXTENSION_DIR")
-        "/usr/lib/guile/2.0"))
+        "/usr/lib/guile/2.2"))
 
   (load-extension (string-append %libdir "/guile-gnutls-v-2")
                   "scm_init_gnutls"))
